==> qtjambi-virtualkeyboard-debuginfo-macos-5.15.17.jar: sources/QtJambiVirtualKeyboard/QVirtualKeyboardAbstractInputMethod_shell.h <==
#ifndef QVIRTUALKEYBOARDABSTRACTINPUTMETHOD_SHELL_H
#define QVIRTUALKEYBOARDABSTRACTINPUTMETHOD_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtVirtualKeyboard/qvirtualkeyboardabstractinputmethod.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtVirtualKeyboard/qvirtualkeyboardinputcontext.h>
#include <QtVirtualKeyboard/qvirtualkeyboardinputengine.h>
#include <QtVirtualKeyboard/qvirtualkeyboardselectionlistmodel.h>
#include <QtVirtualKeyboard/qvirtualkeyboardtrace.h>
#include <QtJambi/RegistryAPI>


class QVirtualKeyboardAbstractInputMethod_shell : public QVirtualKeyboardAbstractInputMethod, public QtJambiShellInterface
{
public:
    QVirtualKeyboardAbstractInputMethod_shell(QObject* parent0 = nullptr);
    ~QVirtualKeyboardAbstractInputMethod_shell() override;

    void childEvent(QChildEvent* event0) override;
    bool clickPreeditText(int cursorPosition0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QList<QVirtualKeyboardInputEngine::InputMode> inputModes(const QString& locale0) override;
    bool keyEvent(Qt::Key key0, const QString& text1, Qt::KeyboardModifiers modifiers2) override;
    QList<QVirtualKeyboardInputEngine::PatternRecognitionMode> patternRecognitionModes() const override;
    bool reselect(int cursorPosition0, const QVirtualKeyboardInputEngine::ReselectFlags& reselectFlags1) override;
    void reset() override;
    QVariant selectionListData(QVirtualKeyboardSelectionListModel::Type type0, int index1, QVirtualKeyboardSelectionListModel::Role role2) override;
    int selectionListItemCount(QVirtualKeyboardSelectionListModel::Type type0) override;
    void selectionListItemSelected(QVirtualKeyboardSelectionListModel::Type type0, int index1) override;
    bool selectionListRemoveItem(QVirtualKeyboardSelectionListModel::Type type0, int index1) override;
    QList<QVirtualKeyboardSelectionListModel::Type> selectionLists() override;
    bool setInputMode(const QString& locale0, QVirtualKeyboardInputEngine::InputMode inputMode1) override;
    bool setTextCase(QVirtualKeyboardInputEngine::TextCase textCase0) override;
    void timerEvent(QTimerEvent* event0) override;
    QVirtualKeyboardTrace* traceBegin(int traceId0, QVirtualKeyboardInputEngine::PatternRecognitionMode patternRecognitionMode1, const QMap<QString, QVariant>& traceCaptureDeviceInfo2, const QMap<QString, QVariant>& traceScreenInfo3) override;
    bool traceEnd(QVirtualKeyboardTrace* trace0) override;
    void update() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVirtualKeyboardAbstractInputMethod_access : public QVirtualKeyboardAbstractInputMethod
{
    jboolean __qt_clickPreeditText_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cursorPosition0);
    jobject __qt_inputModes_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring locale0);
    jboolean __qt_keyEvent_Qt_Key_cref_QString_Qt_KeyboardModifiers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint key0, jstring text1, jint modifiers2);
    jobject __qt_patternRecognitionModes(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_reselect_int_cref_QVirtualKeyboardInputEngine_ReselectFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cursorPosition0, jint reselectFlags1);
    void __qt_reset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_selectionListData_QVirtualKeyboardSelectionListModel_Type_int_QVirtualKeyboardSelectionListModel_Role(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jint index1, jint role2);
    jint __qt_selectionListItemCount_QVirtualKeyboardSelectionListModel_Type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0);
    void __qt_selectionListItemSelected_QVirtualKeyboardSelectionListModel_Type_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jint index1);
    jboolean __qt_selectionListRemoveItem_QVirtualKeyboardSelectionListModel_Type_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jint index1);
    jobject __qt_selectionLists(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_setInputMode_cref_QString_QVirtualKeyboardInputEngine_InputMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring locale0, jint inputMode1);
    jboolean __qt_setTextCase_QVirtualKeyboardInputEngine_TextCase(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint textCase0);
    jobject __qt_traceBegin_int_QVirtualKeyboardInputEngine_PatternRecognitionMode_cref_QMap_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint traceId0, jint patternRecognitionMode1, jobject traceCaptureDeviceInfo2, jobject traceScreenInfo3);
    jboolean __qt_traceEnd_QVirtualKeyboardTrace_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID trace0);
    void __qt_update(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QVIRTUALKEYBOARDABSTRACTINPUTMETHOD_SHELL_H

==> qtjambi-virtualkeyboard-debuginfo-macos-5.15.20.jar: sources/QtJambiVirtualKeyboard/QVirtualKeyboardAbstractInputMethod_shell.h <==
#ifndef QVIRTUALKEYBOARDABSTRACTINPUTMETHOD_SHELL_H
#define QVIRTUALKEYBOARDABSTRACTINPUTMETHOD_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtVirtualKeyboard/qvirtualkeyboardabstractinputmethod.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtVirtualKeyboard/qvirtualkeyboardinputcontext.h>
#include <QtVirtualKeyboard/qvirtualkeyboardinputengine.h>
#include <QtVirtualKeyboard/qvirtualkeyboardselectionlistmodel.h>
#include <QtVirtualKeyboard/qvirtualkeyboardtrace.h>
#include <QtJambi/RegistryAPI>


class QVirtualKeyboardAbstractInputMethod_shell : public QVirtualKeyboardAbstractInputMethod, public QtJambiShellInterface
{
public:
    QVirtualKeyboardAbstractInputMethod_shell(QObject* parent0 = nullptr);
    ~QVirtualKeyboardAbstractInputMethod_shell() override;

    void childEvent(QChildEvent* event0) override;
    bool clickPreeditText(int cursorPosition0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QList<QVirtualKeyboardInputEngine::InputMode> inputModes(const QString& locale0) override;
    bool keyEvent(Qt::Key key0, const QString& text1, Qt::KeyboardModifiers modifiers2) override;
    QList<QVirtualKeyboardInputEngine::PatternRecognitionMode> patternRecognitionModes() const override;
    bool reselect(int cursorPosition0, const QVirtualKeyboardInputEngine::ReselectFlags& reselectFlags1) override;
    void reset() override;
    QVariant selectionListData(QVirtualKeyboardSelectionListModel::Type type0, int index1, QVirtualKeyboardSelectionListModel::Role role2) override;
    int selectionListItemCount(QVirtualKeyboardSelectionListModel::Type type0) override;
    void selectionListItemSelected(QVirtualKeyboardSelectionListModel::Type type0, int index1) override;
    bool selectionListRemoveItem(QVirtualKeyboardSelectionListModel::Type type0, int index1) override;
    QList<QVirtualKeyboardSelectionListModel::Type> selectionLists() override;
    bool setInputMode(const QString& locale0, QVirtualKeyboardInputEngine::InputMode inputMode1) override;
    bool setTextCase(QVirtualKeyboardInputEngine::TextCase textCase0) override;
    void timerEvent(QTimerEvent* event0) override;
    QVirtualKeyboardTrace* traceBegin(int traceId0, QVirtualKeyboardInputEngine::PatternRecognitionMode patternRecognitionMode1, const QMap<QString, QVariant>& traceCaptureDeviceInfo2, const QMap<QString, QVariant>& traceScreenInfo3) override;
    bool traceEnd(QVirtualKeyboardTrace* trace0) override;
    void update() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVirtualKeyboardAbstractInputMethod_access : public QVirtualKeyboardAbstractInputMethod
{
    jboolean __qt_clickPreeditText_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cursorPosition0);
    jobject __qt_inputModes_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring locale0);
    jboolean __qt_keyEvent_Qt_Key_cref_QString_Qt_KeyboardModifiers(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint key0, jstring text1, jint modifiers2);
    jobject __qt_patternRecognitionModes_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_reselect_int_cref_QVirtualKeyboardInputEngine_ReselectFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint cursorPosition0, jint reselectFlags1);
    void __qt_reset(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_selectionListData_QVirtualKeyboardSelectionListModel_Type_int_QVirtualKeyboardSelectionListModel_Role(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jint index1, jint role2);
    jint __qt_selectionListItemCount_QVirtualKeyboardSelectionListModel_Type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0);
    void __qt_selectionListItemSelected_QVirtualKeyboardSelectionListModel_Type_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jint index1);
    jboolean __qt_selectionListRemoveItem_QVirtualKeyboardSelectionListModel_Type_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, jint index1);
    jobject __qt_selectionLists(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_setInputMode_cref_QString_QVirtualKeyboardInputEngine_InputMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring locale0, jint inputMode1);
    jboolean __qt_setTextCase_QVirtualKeyboardInputEngine_TextCase(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint textCase0);
    jobject __qt_traceBegin_int_QVirtualKeyboardInputEngine_PatternRecognitionMode_cref_QMap_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint traceId0, jint patternRecognitionMode1, jobject traceCaptureDeviceInfo2, jobject traceScreenInfo3);
    jboolean __qt_traceEnd_QVirtualKeyboardTrace_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID trace0);
    void __qt_update(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QVIRTUALKEYBOARDABSTRACTINPUTMETHOD_SHELL_H
